==> taskana-core-0.0.6-sources.jar: sql/taskana-schema.sql <==
CREATE TABLE TASKANA_SCHEMA_VERSION(
	ID CHAR(40) NOT NULL,
	VERSION VARCHAR(255) NOT NULL,
	PRIMARY KEY (ID)
);
INSERT INTO TASKANA_SCHEMA_VERSION VALUES ('1', '0.0.1');

CREATE TABLE TASK (
	ID CHAR(40) NOT NULL,
	CREATED TIMESTAMP NULL,
	CLAIMED TIMESTAMP NULL,
	COMPLETED TIMESTAMP NULL,
	MODIFIED TIMESTAMP NULL,
	PLANNED TIMESTAMP NULL,
	DUE TIMESTAMP NULL,
	NAME VARCHAR(255) NULL,
	DESCRIPTION VARCHAR(1024) NULL,
	NOTE VARCHAR(4096) NULL,
	PRIORITY INT NULL,
	STATE VARCHAR(20) NULL,
	CLASSIFICATION_KEY VARCHAR(32) NULL,
	WORKBASKET_KEY VARCHAR(32) NULL,
	DOMAIN VARCHAR(32) NULL,
	BUSINESS_PROCESS_ID VARCHAR(128) NULL,
    PARENT_BUSINESS_PROCESS_ID VARCHAR(128) NULL,
	OWNER VARCHAR(255) NULL,
	POR_COMPANY VARCHAR(32) NOT NULL,
    POR_SYSTEM VARCHAR(32) NOT NULL,
    POR_INSTANCE VARCHAR(32) NOT NULL,
    POR_TYPE VARCHAR(32) NOT NULL,
    POR_VALUE VARCHAR(128) NOT NULL,
	IS_READ BOOLEAN NOT NULL,
	IS_TRANSFERRED BOOLEAN NOT NULL,
	CUSTOM_ATTRIBUTES BLOB NULL,
	CUSTOM_1 VARCHAR(255) NULL,
	CUSTOM_2 VARCHAR(255) NULL,
	CUSTOM_3 VARCHAR(255) NULL,
	CUSTOM_4 VARCHAR(255) NULL,
	CUSTOM_5 VARCHAR(255) NULL,
	CUSTOM_6 VARCHAR(255) NULL,
	CUSTOM_7 VARCHAR(255) NULL,
	CUSTOM_8 VARCHAR(255) NULL,
	CUSTOM_9 VARCHAR(255) NULL,
	CUSTOM_10 VARCHAR(255) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE WORKBASKET(
	ID CHAR(40) NOT NULL,
	KEY VARCHAR(32) NOT NULL,
	CREATED TIMESTAMP NULL,
	MODIFIED TIMESTAMP NULL,
	NAME VARCHAR(255) NOT NULL,
	DOMAIN VARCHAR(32) NOT NULL,
	TYPE VARCHAR(16) NOT NULL,
	DESCRIPTION VARCHAR(255) NULL,
	OWNER VARCHAR(255) NULL,
    CUSTOM_1 VARCHAR(255) NULL,
    CUSTOM_2 VARCHAR(255) NULL,
    CUSTOM_3 VARCHAR(255) NULL,
    CUSTOM_4 VARCHAR(255) NULL,
    ORG_LEVEL_1 VARCHAR(255) NULL,
    ORG_LEVEL_2 VARCHAR(255) NULL,
    ORG_LEVEL_3 VARCHAR(255) NULL,
    ORG_LEVEL_4 VARCHAR(255) NULL,
	PRIMARY KEY (ID),
	CONSTRAINT UC_NAME UNIQUE (ID)
);

CREATE TABLE DISTRIBUTION_TARGETS(
	SOURCE_ID CHAR(40) NOT NULL,
	TARGET_ID CHAR(40) NOT NULL,
	PRIMARY KEY (SOURCE_ID, TARGET_ID)
);

CREATE TABLE CLASSIFICATION(
	ID CHAR(40) NOT NULL,
	KEY VARCHAR(32) NOT NULL,
	PARENT_CLASSIFICATION_KEY VARCHAR(32) NOT NULL,
	CATEGORY VARCHAR(32),
    TYPE VARCHAR(32),
    DOMAIN VARCHAR(255) NOT NULL,
    VALID_IN_DOMAIN BOOLEAN NOT NULL,
	CREATED DATE NULL,
	NAME VARCHAR(255) NULL,
	DESCRIPTION VARCHAR(255) NULL,
	PRIORITY INT NULL,
	SERVICE_LEVEL VARCHAR(255) NULL,
	APPLICATION_ENTRY_POINT VARCHAR(255) NULL,
	CUSTOM_1 VARCHAR(255) NULL,
	CUSTOM_2 VARCHAR(255) NULL,
	CUSTOM_3 VARCHAR(255) NULL,
	CUSTOM_4 VARCHAR(255) NULL,
	CUSTOM_5 VARCHAR(255) NULL,
	CUSTOM_6 VARCHAR(255) NULL,
	CUSTOM_7 VARCHAR(255) NULL,
	CUSTOM_8 VARCHAR(255) NULL
);

CREATE TABLE WORKBASKET_ACCESS_LIST(
	ID CHAR(40) NOT NULL,
	WORKBASKET_KEY VARCHAR(32) NOT NULL,
	ACCESS_ID VARCHAR(255) NULL,
	PERM_READ BOOLEAN NOT NULL,
	PERM_OPEN BOOLEAN NOT NULL,
	PERM_APPEND BOOLEAN NOT NULL,
	PERM_TRANSFER BOOLEAN NOT NULL,
	PERM_DISTRIBUTE BOOLEAN NOT NULL,
	PERM_CUSTOM_1 BOOLEAN NOT NULL,
	PERM_CUSTOM_2 BOOLEAN NOT NULL,
	PERM_CUSTOM_3 BOOLEAN NOT NULL,
	PERM_CUSTOM_4 BOOLEAN NOT NULL,
	PERM_CUSTOM_5 BOOLEAN NOT NULL,
	PERM_CUSTOM_6 BOOLEAN NOT NULL,
	PERM_CUSTOM_7 BOOLEAN NOT NULL,
	PERM_CUSTOM_8 BOOLEAN NOT NULL,
	PERM_CUSTOM_9 BOOLEAN NOT NULL,
	PERM_CUSTOM_10 BOOLEAN NOT NULL,
	PERM_CUSTOM_11 BOOLEAN NOT NULL,
	PERM_CUSTOM_12 BOOLEAN NOT NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE OBJECT_REFERENCE(
	ID CHAR(40) NOT NULL,
	COMPANY VARCHAR(32) NOT NULL,
	SYSTEM VARCHAR(32) NOT NULL,
	SYSTEM_INSTANCE VARCHAR(32) NOT NULL,
	TYPE VARCHAR(32) NOT NULL,
	VALUE VARCHAR(128) NOT NULL
);

CREATE TABLE ATTACHMENT(
    ID CHAR(40) NOT NULL,
    TASK_ID CHAR(40) NOT NULL,
    CREATED TIMESTAMP NULL,
    MODIFIED TIMESTAMP NULL,
    CLASSIFICATION_KEY VARCHAR(32) NULL,
    REF_COMPANY VARCHAR(32) NOT NULL,
    REF_SYSTEM VARCHAR(32) NOT NULL,
    REF_INSTANCE VARCHAR(32) NOT NULL,
    REF_TYPE VARCHAR(32) NOT NULL,
    REF_VALUE VARCHAR(128) NOT NULL,
    CHANNEL VARCHAR(64) NULL,
    RECEIVED TIMESTAMP NULL,
    CUSTOM_ATTRIBUTES BLOB NULL,
    PRIMARY KEY (ID)
);

==> taskana-core-0.0.7-sources.jar: sql/taskana-schema.sql <==
CREATE TABLE TASKANA_SCHEMA_VERSION(
	ID CHAR(40) NOT NULL,
	VERSION VARCHAR(255) NOT NULL,
	PRIMARY KEY (ID)
);
INSERT INTO TASKANA_SCHEMA_VERSION VALUES ('1', '0.0.1');

CREATE TABLE TASK (
	ID CHAR(40) NOT NULL,
	CREATED TIMESTAMP NULL,
	CLAIMED TIMESTAMP NULL,
	COMPLETED TIMESTAMP NULL,
	MODIFIED TIMESTAMP NULL,
	PLANNED TIMESTAMP NULL,
	DUE TIMESTAMP NULL,
	NAME VARCHAR(255) NULL,
	DESCRIPTION VARCHAR(1024) NULL,
	NOTE VARCHAR(4096) NULL,
	PRIORITY INT NULL,
	STATE VARCHAR(20) NULL,
	CLASSIFICATION_KEY VARCHAR(32) NULL,
	CLASSIFICATION_CATEGORY VARCHAR(32),
	WORKBASKET_KEY VARCHAR(64) NULL,
	DOMAIN VARCHAR(32) NULL,
	BUSINESS_PROCESS_ID VARCHAR(128) NULL,
    PARENT_BUSINESS_PROCESS_ID VARCHAR(128) NULL,
	OWNER VARCHAR(255) NULL,
	POR_COMPANY VARCHAR(32) NOT NULL,
    POR_SYSTEM VARCHAR(32) NOT NULL,
    POR_INSTANCE VARCHAR(32) NOT NULL,
    POR_TYPE VARCHAR(32) NOT NULL,
    POR_VALUE VARCHAR(128) NOT NULL,
	IS_READ BOOLEAN NOT NULL,
	IS_TRANSFERRED BOOLEAN NOT NULL,
	CUSTOM_ATTRIBUTES BLOB NULL,
	CUSTOM_1 VARCHAR(255) NULL,
	CUSTOM_2 VARCHAR(255) NULL,
	CUSTOM_3 VARCHAR(255) NULL,
	CUSTOM_4 VARCHAR(255) NULL,
	CUSTOM_5 VARCHAR(255) NULL,
	CUSTOM_6 VARCHAR(255) NULL,
	CUSTOM_7 VARCHAR(255) NULL,
	CUSTOM_8 VARCHAR(255) NULL,
	CUSTOM_9 VARCHAR(255) NULL,
	CUSTOM_10 VARCHAR(255) NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE WORKBASKET(
	ID CHAR(40) NOT NULL,
	KEY VARCHAR(64) NOT NULL,
	CREATED TIMESTAMP NULL,
	MODIFIED TIMESTAMP NULL,
	NAME VARCHAR(255) NOT NULL,
	DOMAIN VARCHAR(32) NOT NULL,
	TYPE VARCHAR(16) NOT NULL,
	DESCRIPTION VARCHAR(255) NULL,
	OWNER VARCHAR(255) NULL,
    CUSTOM_1 VARCHAR(255) NULL,
    CUSTOM_2 VARCHAR(255) NULL,
    CUSTOM_3 VARCHAR(255) NULL,
    CUSTOM_4 VARCHAR(255) NULL,
    ORG_LEVEL_1 VARCHAR(255) NULL,
    ORG_LEVEL_2 VARCHAR(255) NULL,
    ORG_LEVEL_3 VARCHAR(255) NULL,
    ORG_LEVEL_4 VARCHAR(255) NULL,
	PRIMARY KEY (ID),
	CONSTRAINT UC_NAME UNIQUE (ID)
);

CREATE TABLE DISTRIBUTION_TARGETS(
	SOURCE_ID CHAR(40) NOT NULL,
	TARGET_ID CHAR(40) NOT NULL,
	PRIMARY KEY (SOURCE_ID, TARGET_ID)
);

CREATE TABLE CLASSIFICATION(
	ID CHAR(40) NOT NULL,
	KEY VARCHAR(32) NOT NULL,
	PARENT_ID VARCHAR(40) NOT NULL,
	CATEGORY VARCHAR(32),
    TYPE VARCHAR(32),
    DOMAIN VARCHAR(255) NOT NULL,
    VALID_IN_DOMAIN BOOLEAN NOT NULL,
	CREATED TIMESTAMP NULL,
	NAME VARCHAR(255) NULL,
	DESCRIPTION VARCHAR(255) NULL,
	PRIORITY INT NULL,
	SERVICE_LEVEL VARCHAR(255) NULL,
	APPLICATION_ENTRY_POINT VARCHAR(255) NULL,
	CUSTOM_1 VARCHAR(255) NULL,
	CUSTOM_2 VARCHAR(255) NULL,
	CUSTOM_3 VARCHAR(255) NULL,
	CUSTOM_4 VARCHAR(255) NULL,
	CUSTOM_5 VARCHAR(255) NULL,
	CUSTOM_6 VARCHAR(255) NULL,
	CUSTOM_7 VARCHAR(255) NULL,
	CUSTOM_8 VARCHAR(255) NULL
);

CREATE TABLE WORKBASKET_ACCESS_LIST(
	ID CHAR(40) NOT NULL,
	WORKBASKET_KEY VARCHAR(64) NOT NULL,
	ACCESS_ID VARCHAR(255) NULL,
	PERM_READ BOOLEAN NOT NULL,
	PERM_OPEN BOOLEAN NOT NULL,
	PERM_APPEND BOOLEAN NOT NULL,
	PERM_TRANSFER BOOLEAN NOT NULL,
	PERM_DISTRIBUTE BOOLEAN NOT NULL,
	PERM_CUSTOM_1 BOOLEAN NOT NULL,
	PERM_CUSTOM_2 BOOLEAN NOT NULL,
	PERM_CUSTOM_3 BOOLEAN NOT NULL,
	PERM_CUSTOM_4 BOOLEAN NOT NULL,
	PERM_CUSTOM_5 BOOLEAN NOT NULL,
	PERM_CUSTOM_6 BOOLEAN NOT NULL,
	PERM_CUSTOM_7 BOOLEAN NOT NULL,
	PERM_CUSTOM_8 BOOLEAN NOT NULL,
	PERM_CUSTOM_9 BOOLEAN NOT NULL,
	PERM_CUSTOM_10 BOOLEAN NOT NULL,
	PERM_CUSTOM_11 BOOLEAN NOT NULL,
	PERM_CUSTOM_12 BOOLEAN NOT NULL,
	PRIMARY KEY (ID)
);

CREATE TABLE OBJECT_REFERENCE(
	ID CHAR(40) NOT NULL,
	COMPANY VARCHAR(32) NOT NULL,
	SYSTEM VARCHAR(32) NOT NULL,
	SYSTEM_INSTANCE VARCHAR(32) NOT NULL,
	TYPE VARCHAR(32) NOT NULL,
	VALUE VARCHAR(128) NOT NULL
);

CREATE TABLE ATTACHMENT(
    ID CHAR(40) NOT NULL,
    TASK_ID CHAR(40) NOT NULL,
    CREATED TIMESTAMP NULL,
    MODIFIED TIMESTAMP NULL,
    CLASSIFICATION_KEY VARCHAR(32) NULL,
    REF_COMPANY VARCHAR(32) NOT NULL,
    REF_SYSTEM VARCHAR(32) NOT NULL,
    REF_INSTANCE VARCHAR(32) NOT NULL,
    REF_TYPE VARCHAR(32) NOT NULL,
    REF_VALUE VARCHAR(128) NOT NULL,
    CHANNEL VARCHAR(64) NULL,
    RECEIVED TIMESTAMP NULL,
    CUSTOM_ATTRIBUTES BLOB NULL,
    PRIMARY KEY (ID)
);
